# django-vises

![GitHub License](https://img.shields.io/github/license/rexzhang/django-vises)
[![PyPI - Version](https://img.shields.io/pypi/v/django-vises)](https://pypi.org/project/django-vises/)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https://raw.githubusercontent.com/rexzhang/django-vises/main/pyproject.toml)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-vises)](https://pypi.org/project/django-vises/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/django-vises)](https://pypi.org/project/django-vises/)

## Changelog

### 1.5.0 - 20251203

- refactor: remove funcs manager from abstract models

### 1.4.0 - 20251201

- refactor: change default cache backend to DummyCache
- feat: add database URI options parser

### 1.3.2 - 20251125

- feat: enhance database URI parsing and add tests
- refactor: rename objects to funcs in model managers
- refactor: use composite primary key for group and key fields

### 1.2.1 - 20251123

- refactor: migrate redis dataset to MutableSet implementation
- feat: reorganize env vars and add cache settings
- fix: vises influxdb2

### 1.0.3 - 20251115

- first public release
